@@ -10,6 +10,9 @@
 #define PCW_SETTING_WIDTH "profilechangerwidget/width"
 #define PCW_SETTING_OPACITY "profilechangerwidget/opacity"
 #define PCW_SETTING_SHOWNEXTPROFILE "profilechangerwidget/showNextProfile"
+#define PCW_SETTING_LASTVERSION "profilechangerwidget/lastVersion"
+#define PCW_SETTING_LASTVERSION_DEFAULT "0.0"
+#define PCW_APP_VERSION "0.9.2"
 
 namespace Ui {
     class SettingsDialog;
@@ -25,11 +28,13 @@ signals:
 public:
     explicit SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
+    void checkVersion();
 
 private:
     Ui::SettingsDialog *ui;
     void openBrowser(QString url);
     void showInformation(QString info);
+    void showQuestion(QString info);
 
 private slots:
     void accept();
